<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>プログラムの名前</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>使い方</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Dock Preview</source>
        <translation>Dock プレビュー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Add New Application</source>
        <translation>新しいアプリの追加</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Add application</source>
        <translation>アプリの追加</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Delete this application</source>
        <translation>このアプリを削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Border</source>
        <translation>罫線</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Background</source>
        <translation>バックグラウンド</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Back</source>
        <translation>戻る</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <location filename="../mainwindow.cpp" line="788"/>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Select icon...</source>
        <translation>アイコンの選択...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <location filename="../mainwindow.cpp" line="89"/>
        <location filename="../mainwindow.cpp" line="646"/>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="791"/>
        <source>Select...</source>
        <translation>選択...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Move right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Move left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Display help </source>
        <translation>ヘルプの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="580"/>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. アプリケーションを1つずつドックに追加します
2. .desktop ファイルを選択するか、必要なアプリケーションのコマンドを入力します。
3. アイコンのサイズ、背景（黒が標準）、枠線の属性を選択します。
4. 「アプリケーションの追加」を押して続行するか、「保存」を押して終了します。</translation>
    </message>
    <message>
        <source>black</source>
        <translation type="vanished">black</translation>
    </message>
    <message>
        <source>white</source>
        <translation type="vanished">white</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>このツールでは、1つ以上のアプリケーションで新しい dock を作成することができます。また、以前に作成した dock を編集したり削除したりすることもできます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>Operation mode</source>
        <translation>動作モード</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>&amp;Close</source>
        <translation>&amp;終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>&amp;Delete</source>
        <translation>&amp;削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>&amp;Edit</source>
        <translation>&amp;編集</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Dock name</source>
        <translation>Dock の名前</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>メニューに表示する名前を入力：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Select dock to delete</source>
        <translation>削除する dock の選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>本当に %1 を削除しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Next</source>
        <translation>次</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Select dock to move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="353"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>Could not open file</source>
        <translation>ファイルを開くことができません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Overwrite?</source>
        <translation>上書きしますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>dock ファイルを上書きしますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Save file</source>
        <translation>ファイルの保存</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Dock saved</source>
        <translation>Dock を保存しました</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>dock が保存されました。

新しく作成した dock を編集するには、「既存の dock 編集」を選択してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>About %1</source>
        <translation> %1について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>Description goes here</source>
        <translation>説明はここにあります</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Select .desktop file</source>
        <translation>.desktop ファイルを選択してください</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>デスクトップファイル (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Select a dock file</source>
        <translation>dock ファイルの選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>No file selected</source>
        <translation>選択ファイルなし</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>編集する dock ファイルが選択されていません。代わりに新しい dock を作成します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>選択したファイルを開くことができません。代わりに新しい dock を作成します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. 「戻る」ボタンと「次へ」ボタンを使って、アプリケーションを1つずつ編集します。
2. 好きなようにアプリケーションを追加したり削除します
3. 完了したら、「保存」をクリックします。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Select icon</source>
        <translation>アイコンの選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>アイコン (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Dock の場所</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>上中央</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>左下</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>下中央</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>左上</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>右上</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>左中央</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>右中央</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>下中央</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>右上</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>左上</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>左下</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>右下</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>dock の場所を選択</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>このプログラムは標準ユーザーで実行しなくてはなりません。</translation>
    </message>
</context>
</TS>
